from pathlib import Path
from typing import Any, Dict, Optional

import click
import pandas


def _read_excel(xlsx_file: str, sheet_name: Optional[str]) -> pandas.DataFrame:
    read_excel_kwargs: Dict[str, Any] = {"header": None}
    if sheet_name is not None:
        read_excel_kwargs.update({"sheet_name": sheet_name})
    return pandas.read_excel(xlsx_file, **read_excel_kwargs)


def _to_csv(
    df: pandas.DataFrame, csv_file: str, sep: str, encoding: str, quotechar: str
) -> None:
    Path(csv_file).parent.mkdir(exist_ok=True, parents=True)

    to_csv_kwargs = {
        "sep": sep,
        "encoding": encoding,
        "quotechar": quotechar,
        "header": False,
        "index": False,
    }
    df.to_csv(csv_file, **to_csv_kwargs)


@click.command(name="xlsx2csv", help="Convert xlsx file to csv file.")
@click.argument("xlsx_file")
@click.argument("csv_file", required=False)
@click.option(
    "--sheet_name",
    help="Sheet name when reading xlsx. If not specified, read 1st sheet.",
)
@click.option(
    "--sep", default=",", show_default=True, help="Field delimiter for the output file."
)
@click.option(
    "--encoding",
    default="utf-8",
    show_default=True,
    help="A string representing the encoding to use in the output file.",
)
@click.option(
    "--quotechar", default='"', help="Character used to quote fields.",
)
def xlsx2csv(
    xlsx_file: str,
    csv_file: Optional[str],
    sheet_name: Optional[str],
    sep: str,
    encoding: str,
    quotechar: str,
):
    df = _read_excel(xlsx_file, sheet_name=sheet_name)
    if csv_file is None:
        xlsx_file_path = Path(xlsx_file)
        csv_file_name = f"{xlsx_file_path.stem}.csv"
        csv_file = str(xlsx_file_path.parent / csv_file_name)

    _to_csv(df, csv_file, sep=sep, encoding=encoding, quotechar=quotechar)



import click

import convpandas
from convpandas.command.csv2xlsx import csv2xlsx
from convpandas.command.xlsx2csv import xlsx2csv


@click.group()
@click.version_option(version=convpandas.__version__)
def cli():
    pass


cli.add_command(csv2xlsx)
cli.add_command(xlsx2csv)

if __name__ == "__main__":
    cli()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['convpandas', 'convpandas.command']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.1.2,<8.0.0',
 'openpyxl>=3.0.3,<4.0.0',
 'pandas>=1.0.3,<2.0.0',
 'xlrd>=1.2.0,<2.0.0']

entry_points = \
{'console_scripts': ['convpandas = convpandas.__main__:cli']}

setup_kwargs = {
    'name': 'convpandas',
    'version': '0.1.1',
    'description': 'Convert file format with pandas',
    'long_description': '# convert-fileformat-with-pandas\nConvert file format with pandas\n\n[![Build Status](https://travis-ci.org/yuji38kwmt/convpandas.svg?branch=master)](https://travis-ci.org/yuji38kwmt/convpandas)\n[![PyPI version](https://badge.fury.io/py/convpandas.svg)](https://badge.fury.io/py/convpandas)\n[![Python Versions](https://img.shields.io/pypi/pyversions/convpandas.svg)](https://pypi.org/project/convpandas/)\n\n# Requirements\n* Python 3.6+\n\n# Install\n\n```\n$ pip install convpandas\n```\n\nhttps://pypi.org/project/convpandas/\n\n\n# Usage\n\n## csv2xlsx\nConvert csv file to xlsx file.\n\n```\n$ convpandas csv2xlsx in.csv out.xlsx\n```\n\n### Options\n\n```\nOptions:\n  --sep TEXT                   Delimiter to use when reading csv.  [default:,]\n  --encoding TEXT              Encoding to use when reading csv. List of Python standard encodings .  [default: utf-8]\n  --quotechar TEXT             The character used to denote the start and end of a quoted item when reading csv.\n  --string_to_numeric BOOLEAN  If true, convert string to numeric. [default: utf-8]\n```\n\n## xlsx2csv\nConvert xlsx file to csv file.\n\n```\n$ convpandas xlsx2csv in.xlsx out.csv\n```\n\n\n```\nOptions:\n  --sheet_name TEXT  Sheet name when reading xlsx. If not specified, read 1st sheet.\n  --sep TEXT         Field delimiter for the output file.  [default: ,]\n  --encoding TEXT    A string representing the encoding to use in the output file.  [default: utf-8]\n  --quotechar TEXT   Character used to quote fields.\n```\n',
    'author': 'yuji38kwmt',
    'author_email': 'yuji38kwmt@yahoo.co.jp',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/yuji38kwmt/convert-fileformat-with-pandas.git',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from pathlib import Path
from typing import Optional

import click
import openpyxl
import pandas


def _read_csv(
    csv_file: str, sep: str, encoding: str, quotechar: Optional[str],
) -> pandas.DataFrame:
    read_csv_kwargs = {
        "sep": sep,
        "encoding": encoding,
        "header": None,
    }
    if quotechar is not None:
        read_csv_kwargs.update({"quotechar": quotechar})
    return pandas.read_csv(csv_file, **read_csv_kwargs)


def _to_numeric(value):
    return pandas.to_numeric(value, errors="ignore")


def _do_not_anything(value):
    return value


def _to_excel(
    df: pandas.DataFrame, xlsx_file: str, string_to_numeric: bool = True,
) -> None:
    Path(xlsx_file).parent.mkdir(exist_ok=True, parents=True)
    if string_to_numeric:
        convert_func = _to_numeric
    else:
        convert_func = _do_not_anything

    workbook = openpyxl.Workbook(write_only=True)
    worksheet = workbook.create_sheet()
    for row_index, row in df.iterrows():
        worksheet.append([convert_func(value) for value in row])
    workbook.save(xlsx_file)


@click.command(name="csv2xlsx", help="Convert csv file to xlsx file.")
@click.argument("csv_file")
@click.argument("xlsx_file", required=False)
@click.option(
    "--sep", default=",", show_default=True, help="Delimiter to use when reading csv."
)
@click.option(
    "--encoding",
    default="utf-8",
    show_default=True,
    help="Encoding to use when reading csv. List of Python standard encodings .",
)
@click.option(
    "--quotechar",
    help="The character used to denote the start and end of a quoted item when reading csv.",
)
@click.option(
    "--string_to_numeric",
    type=bool,
    default=True,
    help="If true, convert string to numeric. [default: utf-8]",
)
def csv2xlsx(
    csv_file: str,
    xlsx_file: Optional[str],
    sep: str,
    encoding: str,
    quotechar: Optional[str],
    string_to_numeric: bool,
):
    df = _read_csv(csv_file, sep=sep, encoding=encoding, quotechar=quotechar)
    if xlsx_file is None:
        csv_file_path = Path(csv_file)
        xlsx_file_name = f"{csv_file_path.stem}.xlsx"
        xlsx_file = str(csv_file_path.parent / xlsx_file_name)
    _to_excel(df=df, xlsx_file=xlsx_file, string_to_numeric=string_to_numeric)
